@@ -13,7 +13,7 @@ int main(int argc, char **argv)
 	
 	getloadavg(loadavg, 3);
 
-	printf(" %s %.2f, %.2f, %.2f\n",
+	printf(" %s %.2f, %.2f, %.2f",
 		date, loadavg[0], loadavg[1], loadavg[2]);
 
 	return(0);
